pub async fn update_email_for_user_by_id(
conn: &mut PgConnection,
user_id: Uuid,
new_email: &str,
) -> ModelResult<()>Expand description
Points the account at a new address by user id rather than upstream id, for accounts (e.g. local-only ones) that have no upstream id. Same effect as update_email_for_user otherwise.